=== modified file 'loggerhead/config.py'
--- loggerhead/config.py	2009-03-31 16:34:57 +0000
+++ loggerhead/config.py	2009-03-31 18:10:31 +0000
@@ -1,7 +1,54 @@
 '''Configuration tools for Loggerhead.'''
+from optparse import OptionParser
+import sys
+
+
+def command_line_parser():
+    parser = OptionParser("%prog [options] <path>")
+    parser.set_defaults(
+        user_dirs=False,
+        show_version=False,
+        log_folder=None,
+        )
+    parser.add_option("--user-dirs", action="store_true", dest="user_dirs",
+                      help="Serve user directories as ~user.")
+    parser.add_option("--trunk-dir", metavar="DIR",
+                      help="The directory that contains the trunk branches.")
+    parser.add_option("--port", dest="user_port",
+                      help=("Port Loggerhead should listen on "
+                            "(defaults to 8080)."))
+    parser.add_option("--host", dest="user_host",
+                      help="Host Loggerhead should listen on.")
+    parser.add_option('--memory-profile', action='store_true',
+                      dest='memory_profile',
+                      help='Profile the memory usage using heapy.')
+    parser.add_option("--prefix", dest="user_prefix",
+                      help="Specify host prefix.")
+    parser.add_option("--profile", action="store_true", dest="profile",
+                      help="Generate callgrind profile data to "
+                        "%d-stats.callgrind on each request.")
+    parser.add_option("--reload", action="store_true", dest="reload",
+                      help="Restarts the application when changing python"
+                           " files. Only used for development purposes.")
+    parser.add_option('--log-folder', dest="log_folder",
+                      type=str, help="The directory to place log files in.")
+    parser.add_option("--version", action="store_true", dest="show_version",
+                      help="Print the software version and exit")
+    return parser
 
 
 class LoggerheadConf:
     '''A configuration object.'''
 
+    def __init__(self):
+        parser = command_line_parser()
+        self._options, self._args = parser.parse_args(sys.argv[1:])
+
+    def get_option(self, option):
+        '''Get an option from the options dict.'''
+        return self._options.__dict__[option]
+
+    def get_arg(self, index):
+        '''Get an arg from the arg list.'''
+        return self._args(index)
 

=== modified file 'serve-branches'
--- serve-branches	2009-03-30 22:11:06 +0000
+++ serve-branches	2009-03-31 18:10:31 +0000
@@ -19,8 +19,6 @@
 import os
 import sys
 
-from optparse import OptionParser
-
 from bzrlib.plugin import load_plugins
 
 from paste import httpserver
@@ -30,44 +28,11 @@
 from loggerhead import __version__
 from loggerhead.apps.filesystem import (
     BranchesFromFileSystemRoot, UserBranchesFromFileSystemRoot)
+from loggerhead.config import command_line_parser
 from loggerhead.util import Reloader
 from loggerhead.apps.error import ErrorHandlerApp
 
 
-def command_line_parser():
-    parser = OptionParser("%prog [options] <path>")
-    parser.set_defaults(
-        user_dirs=False,
-        show_version=False,
-        log_folder=None,
-        )
-    parser.add_option("--user-dirs", action="store_true", dest="user_dirs",
-                      help="Serve user directories as ~user.")
-    parser.add_option("--trunk-dir", metavar="DIR",
-                      help="The directory that contains the trunk branches.")
-    parser.add_option("--port", dest="user_port",
-                      help=("Port Loggerhead should listen on "
-                            "(defaults to 8080)."))
-    parser.add_option("--host", dest="user_host",
-                      help="Host Loggerhead should listen on.")
-    parser.add_option('--memory-profile', action='store_true',
-                      dest='memory_profile',
-                      help='Profile the memory usage using heapy.')
-    parser.add_option("--prefix", dest="user_prefix",
-                      help="Specify host prefix.")
-    parser.add_option("--profile", action="store_true", dest="profile",
-                      help="Generate callgrind profile data to "
-                        "%d-stats.callgrind on each request.")
-    parser.add_option("--reload", action="store_true", dest="reload",
-                      help="Restarts the application when changing python"
-                           " files. Only used for development purposes.")
-    parser.add_option('--log-folder', dest="log_folder",
-                      type=str, help="The directory to place log files in.")
-    parser.add_option("--version", action="store_true", dest="show_version",
-                      help="Print the software version and exit")
-    return parser
-
-
 def main(args):
     parser = command_line_parser()
     (options, args) = parser.parse_args(sys.argv[1:])

